@@ -5,4 +5,6 @@ from cryptodatapi.news import *
 from cryptodatapi.derivatives import *
 from cryptodatapi.dex import *
 from cryptodatapi.lending import *
-from cryptodatapi.spot import *
\ No newline at end of file
+from cryptodatapi.spot import *
+from cryptodatapi.gainers import *
+from cryptodatapi.losers import *
\ No newline at end of file
